==> xpuzzles_7.3.2.orig.tar.gz: xpuzzles-7.3.2/oct/Oct.h <==
/*-
# X-BASED OCTAHEDRON
#
#  Oct.h
#
###
#
#  Copyright (c) 1994 - 2007	David Albert Bagley, bagleyd@tux.org
#
#                   All Rights Reserved
#
#  Permission to use, copy, modify, and distribute this software and
#  its documentation for any purpose and without fee is hereby granted,
#  provided that the above copyright notice appear in all copies and
#  that both that copyright notice and this permission notice appear in
#  supporting documentation, and that the name of the author not be
#  used in advertising or publicity pertaining to distribution of the
#  software without specific, written prior permission.
#
#  This program is distributed in the hope that it will be "playable",
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
*/

/* Public header file for Oct */

#ifndef _XtOct_h
#define _XtOct_h

/***********************************************************************
 *
 * Oct Widget
 *
 ***********************************************************************/

#ifndef WINVER
#define XtNmono ((char *) "mono")
#define XtNframeColor ((char *) "frameColor")
#define XtNfaceColor0 ((char *) "faceColor0")
#define XtNfaceColor1 ((char *) "faceColor1")
#define XtNfaceColor2 ((char *) "faceColor2")
#define XtNfaceColor3 ((char *) "faceColor3")
#define XtNfaceColor4 ((char *) "faceColor4")
#define XtNfaceColor5 ((char *) "faceColor5")
#define XtNfaceColor6 ((char *) "faceColor6")
#define XtNfaceColor7 ((char *) "faceColor7")
#define XtNpieceBorder ((char *) "pieceBorder")
#define XtNdelay ((char *) "delay")
#define XtNsound ((char *) "sound")
#define XtNmoveSound ((char *) "moveSound")
#define XtNsize ((char *) "size")
#define XtNsticky ((char *) "sticky")
#define XtNmode ((char *) "mode")
#define XtNorient ((char *) "orient")
#define XtNpractice ((char *) "practice")
#define XtNuserName ((char *) "userName")
#define XtNscoreFile ((char *) "scoreFile")
#define XtNscoreOnly ((char *) "scoreOnly")
#define XtNversionOnly ((char *) "versionOnly")
#define XtNmenu ((char *) "menu")
#define XtNstart ((char *) "start")
#define XtNcheat ((char *) "cheat")
#define XtNpixmapSize ((char *) "pixmapSize")
#define XtNselectCallback ((char *) "selectCallback")
#define XtCMono ((char *) "Mono")
#define XtCDelay ((char *) "Delay")
#define XtCSound ((char *) "Sound")
#define XtCMoveSound ((char *) "MoveSound")
#define XtCSize ((char *) "Size")
#define XtCSticky ((char *) "Sticky")
#define XtCMode ((char *) "Mode")
#define XtCOrient ((char *) "Orient")
#define XtCPractice ((char *) "Practice")
#define XtCUserName ((char *) "UserName")
#define XtCScoreFile ((char *) "ScoreFile")
#define XtCMenu ((char *) "Menu")
#define XtCPixmapSize ((char *) "PixmapSize")

typedef struct _OctClassRec *OctWidgetClass;

extern WidgetClass octWidgetClass;

typedef struct {
	XEvent     *event;
	int         reason;
} octCallbackStruct;
#endif

#define ACTION_GET 100
#define ACTION_WRITE 101
#define ACTION_EXIT 102
#define ACTION_HIDE 103
#define ACTION_PRACTICE_QUERY 104
#define ACTION_RANDOMIZE_QUERY 105
#define ACTION_SOLVE_MESSAGE 106
#define ACTION_RESTORE 107
#define ACTION_RESET 108
#define ACTION_AMBIGUOUS 109
#define ACTION_ILLEGAL 110
#define ACTION_MOVED 111
#define ACTION_CONTROL 112
#define ACTION_SOLVED 113
#define ACTION_COMPUTED 114
#define ACTION_UNDO 200
#define ACTION_REDO 201
#define ACTION_CLEAR 202
#define ACTION_PRACTICE 203
#define ACTION_RANDOMIZE 204
#define ACTION_SOLVE 205
#define ACTION_INCREMENT 206
#define ACTION_DECREMENT 207
#define ACTION_ORIENTIZE 208
#define ACTION_STICKY 209
#define ACTION_SPEED 210
#define ACTION_SLOW 211
#define ACTION_SOUND 212
#define ACTION_TOP 300
#define ACTION_TR 301
#define ACTION_RIGHT 302
#define ACTION_BR 303
#define ACTION_BOTTOM 304
#define ACTION_BL 305
#define ACTION_LEFT 306
#define ACTION_TL 307
#define ACTION_CW 309
#define ACTION_CCW 315
#define ACTION_SHIFT_TOP 320
#define ACTION_SHIFT_TR 321
#define ACTION_SHIFT_RIGHT 322
#define ACTION_SHIFT_BR 323
#define ACTION_SHIFT_BOTTOM 324
#define ACTION_SHIFT_BL 325
#define ACTION_SHIFT_LEFT 326
#define ACTION_SHIFT_TL 327
#define ACTION_SHIFT_CW 329
#define ACTION_SHIFT_CCW 335
#define ACTION_CONTROL_TOP 340
#define ACTION_CONTROL_TR 341
#define ACTION_CONTROL_RIGHT 342
#define ACTION_CONTROL_BR 343
#define ACTION_CONTROL_BOTTOM 344
#define ACTION_CONTROL_BL 345
#define ACTION_CONTROL_LEFT 346
#define ACTION_CONTROL_TL 347
#define ACTION_CONTROL_CW 349
#define ACTION_CONTROL_CCW 355
#define ACTION_SHIFTCONTROL_TOP 360
#define ACTION_SHIFTCONTROL_TR 361
#define ACTION_SHIFTCONTROL_RIGHT 362
#define ACTION_SHIFTCONTROL_BR 363
#define ACTION_SHIFTCONTROL_BOTTOM 364
#define ACTION_SHIFTCONTROL_BL 365
#define ACTION_SHIFTCONTROL_LEFT 366
#define ACTION_SHIFTCONTROL_TL 367
#define ACTION_SHIFTCONTROL_CW  369
#define ACTION_SHIFTCONTROL_CCW 375
#define ACTION_PERIOD3 400
#define ACTION_PERIOD4 401
#define ACTION_BOTH 402
#define ACTION_DESCRIPTION 900
#define ACTION_FEATURES 901
#define ACTION_REFERENCES 902
#define ACTION_ABOUT 903
#define ACTION_IGNORE 999

#define MINFACETS 1
#define PERIOD3 3
#define PERIOD4 4
#define BOTH 5
#define MAXMODES 3
#define DEFAULTMODE PERIOD4
#define DEFAULTFACETS 3
#define DEFAULTORIENT FALSE
#define DEFAULTPRACTICE TRUE
#define DEFAULTSTICKY FALSE
#ifdef MONOTEST
#define DEFAULTMONO TRUE
#else
#define DEFAULTMONO FALSE
#endif
#define DEFAULTREVERSE FALSE

#define BOOL_STRING(a) ((a==0)?"false":"true")

typedef struct _OctRec *OctWidget;

#endif /* _XtOct_h */
/* DON'T ADD STUFF AFTER THIS #endif */

==> xpuzzles_7.3.3.orig.tar.gz: xpuzzles-7.3.3/oct/Oct.h <==
/*-
# X-BASED OCTAHEDRON
#
#  Oct.h
#
###
#
#  Copyright (c) 1994 - 2007	David A. Bagley, bagleyd@tux.org
#
#                   All Rights Reserved
#
#  Permission to use, copy, modify, and distribute this software and
#  its documentation for any purpose and without fee is hereby granted,
#  provided that the above copyright notice appear in all copies and
#  that both that copyright notice and this permission notice appear in
#  supporting documentation, and that the name of the author not be
#  used in advertising or publicity pertaining to distribution of the
#  software without specific, written prior permission.
#
#  This program is distributed in the hope that it will be "playable",
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
*/

/* Public header file for Oct */

#ifndef _XtOct_h
#define _XtOct_h

/***********************************************************************
 *
 * Oct Widget
 *
 ***********************************************************************/

#ifndef WINVER
#define XtNmono ((char *) "mono")
#define XtNframeColor ((char *) "frameColor")
#define XtNfaceColor0 ((char *) "faceColor0")
#define XtNfaceColor1 ((char *) "faceColor1")
#define XtNfaceColor2 ((char *) "faceColor2")
#define XtNfaceColor3 ((char *) "faceColor3")
#define XtNfaceColor4 ((char *) "faceColor4")
#define XtNfaceColor5 ((char *) "faceColor5")
#define XtNfaceColor6 ((char *) "faceColor6")
#define XtNfaceColor7 ((char *) "faceColor7")
#define XtNpieceBorder ((char *) "pieceBorder")
#define XtNdelay ((char *) "delay")
#define XtNsound ((char *) "sound")
#define XtNmoveSound ((char *) "moveSound")
#define XtNsize ((char *) "size")
#define XtNsticky ((char *) "sticky")
#define XtNmode ((char *) "mode")
#define XtNorient ((char *) "orient")
#define XtNpractice ((char *) "practice")
#define XtNuserName ((char *) "userName")
#define XtNscoreFile ((char *) "scoreFile")
#define XtNscoreOnly ((char *) "scoreOnly")
#define XtNversionOnly ((char *) "versionOnly")
#define XtNmenu ((char *) "menu")
#define XtNstart ((char *) "start")
#define XtNcheat ((char *) "cheat")
#define XtNpixmapSize ((char *) "pixmapSize")
#define XtNselectCallback ((char *) "selectCallback")
#define XtCMono ((char *) "Mono")
#define XtCDelay ((char *) "Delay")
#define XtCSound ((char *) "Sound")
#define XtCMoveSound ((char *) "MoveSound")
#define XtCSize ((char *) "Size")
#define XtCSticky ((char *) "Sticky")
#define XtCMode ((char *) "Mode")
#define XtCOrient ((char *) "Orient")
#define XtCPractice ((char *) "Practice")
#define XtCUserName ((char *) "UserName")
#define XtCScoreFile ((char *) "ScoreFile")
#define XtCMenu ((char *) "Menu")
#define XtCPixmapSize ((char *) "PixmapSize")

typedef struct _OctClassRec *OctWidgetClass;

extern WidgetClass octWidgetClass;

typedef struct {
	XEvent     *event;
	int         reason;
} octCallbackStruct;
#endif

#define ACTION_GET 100
#define ACTION_WRITE 101
#define ACTION_EXIT 102
#define ACTION_HIDE 103
#define ACTION_PRACTICE_QUERY 104
#define ACTION_RANDOMIZE_QUERY 105
#define ACTION_SOLVE_MESSAGE 106
#define ACTION_RESTORE 107
#define ACTION_RESET 108
#define ACTION_AMBIGUOUS 109
#define ACTION_ILLEGAL 110
#define ACTION_MOVED 111
#define ACTION_CONTROL 112
#define ACTION_SOLVED 113
#define ACTION_COMPUTED 114
#define ACTION_UNDO 200
#define ACTION_REDO 201
#define ACTION_CLEAR 202
#define ACTION_PRACTICE 203
#define ACTION_RANDOMIZE 204
#define ACTION_SOLVE 205
#define ACTION_INCREMENT 206
#define ACTION_DECREMENT 207
#define ACTION_ORIENTIZE 208
#define ACTION_STICKY 209
#define ACTION_SPEED 210
#define ACTION_SLOW 211
#define ACTION_SOUND 212
#define ACTION_TOP 300
#define ACTION_TR 301
#define ACTION_RIGHT 302
#define ACTION_BR 303
#define ACTION_BOTTOM 304
#define ACTION_BL 305
#define ACTION_LEFT 306
#define ACTION_TL 307
#define ACTION_CW 309
#define ACTION_CCW 315
#define ACTION_SHIFT_TOP 320
#define ACTION_SHIFT_TR 321
#define ACTION_SHIFT_RIGHT 322
#define ACTION_SHIFT_BR 323
#define ACTION_SHIFT_BOTTOM 324
#define ACTION_SHIFT_BL 325
#define ACTION_SHIFT_LEFT 326
#define ACTION_SHIFT_TL 327
#define ACTION_SHIFT_CW 329
#define ACTION_SHIFT_CCW 335
#define ACTION_CONTROL_TOP 340
#define ACTION_CONTROL_TR 341
#define ACTION_CONTROL_RIGHT 342
#define ACTION_CONTROL_BR 343
#define ACTION_CONTROL_BOTTOM 344
#define ACTION_CONTROL_BL 345
#define ACTION_CONTROL_LEFT 346
#define ACTION_CONTROL_TL 347
#define ACTION_CONTROL_CW 349
#define ACTION_CONTROL_CCW 355
#define ACTION_SHIFT_CONTROL_TOP 360
#define ACTION_SHIFT_CONTROL_TR 361
#define ACTION_SHIFT_CONTROL_RIGHT 362
#define ACTION_SHIFT_CONTROL_BR 363
#define ACTION_SHIFT_CONTROL_BOTTOM 364
#define ACTION_SHIFT_CONTROL_BL 365
#define ACTION_SHIFT_CONTROL_LEFT 366
#define ACTION_SHIFT_CONTROL_TL 367
#define ACTION_SHIFT_CONTROL_CW  369
#define ACTION_SHIFT_CONTROL_CCW 375
#define ACTION_PERIOD3 400
#define ACTION_PERIOD4 401
#define ACTION_BOTH 402
#define ACTION_DESCRIPTION 900
#define ACTION_FEATURES 901
#define ACTION_REFERENCES 902
#define ACTION_ABOUT 903
#define ACTION_IGNORE 999

#define MIN_FACETS 1
#define PERIOD3 3
#define PERIOD4 4
#define BOTH 5
#define MAX_MODES 3
#define DEFAULT_MODE PERIOD4
#define DEFAULTFACETS 3
#define DEFAULT_ORIENT FALSE
#define DEFAULT_PRACTICE TRUE
#define DEFAULTSTICKY FALSE
#ifdef MONOTEST
#define DEFAULT_MONO TRUE
#else
#define DEFAULT_MONO FALSE
#endif
#define DEFAULT_REVERSE FALSE

#define BOOL_STRING(a) ((a==0)?"false":"true")

typedef struct _OctRec *OctWidget;

#endif /* _XtOct_h */
/* DON'T ADD STUFF AFTER THIS #endif */
